# QStyler

![QStyler](https://raw.githubusercontent.com/alexpdev/QStyler/master/assets/QStylerLogo.png)

------------------------------
<!--- These are examples. See https://shields.io for others or to customize this set of shields. You might want to include dependencies, project status and licence info here --->

![GitHub repo size](https://img.shields.io/github/repo-size/alexpdev/qstyler?color=orange)
![GitHub License](https://img.shields.io/github/license/alexpdev/qstyler?color=red&logo=apache)
![PyPI - Downloads](https://img.shields.io/pypi/dm/qstyler?color=brown)
![GitHub Last Commit](https://badgen.net/github/last-commit/alexpdev/qstyler?color=blue&icon=github)
[![CI](https://github.com/alexpdev/QStyler/actions/workflows/pyworkflow.yml/badge.svg?branch=master&event=push)](https://github.com/alexpdev/QStyler/actions/workflows/workflow.yml)
![GitHub repo size](https://img.shields.io/github/repo-size/alexpdev/qstyler)
![GitHub contributors](https://img.shields.io/github/contributors/alexpdev/qstyler)
![GitHub stars](https://img.shields.io/github/stars/alexpdev/qstyler)
![GitHub forks](https://img.shields.io/github/forks/alexpdev/qstyler)

## 🌐 Overview

GUI tool for testing Qt StyleSheets and their effect on widgets.

## Prerequisites

Before you begin, ensure you have met the following requirements:

<!--- These are just example requirements. Add, duplicate or remove as required --->

* You have installed the latest version of `python3`
* You have installed `PySide6`.

## Installing QStyler

To install QStyler, follow these steps:

```bash
git clone https://github.com/alexpdev/qstyler.git
cd qstyler
pip install .
qstyler
```

## Contributing to QStyler
<!--- If your README is long or you have some specific process or steps you want contributors to follow, consider creating a separate CONTRIBUTING.md file--->
To contribute to QStyler, follow these steps:

1. Fork this repository.
2. Create a branch: `git checkout -b <branch_name>`.
3. Make your changes and commit them: `git commit -m '<commit_message>'`
4. Push to the original branch: `git push origin <project_name>/<location>`
5. Create the pull request.

Alternatively see the GitHub documentation on [creating a pull request](https://help.github.com/en/github/collaborating-with-issues-and-pull-requests/creating-a-pull-request).

## License

<!--- If you're not sure which open license to use see https://choosealicense.com/--->

This project uses the following license: Apache 2.0.
